@@ -82,13 +82,13 @@ void Form2::pwrBtn()
     on_btn->setEnabled(FALSE);
     // The serial port you want to use
     if(port1RB->isChecked()){
-	spt = 1;
+	spt = "/dev/ttyS0";
     }
     if(port2RB->isChecked()){
-	spt = 2;
+	spt = "/dev/ttyS1";
     }
     if(port3RB->isChecked()){
-	spt = 3;
+	spt = lineEdit38->displayText();
     }   
     k2tr.init_k2(spt);// Initialize the serial port
     pwrLight->setPixmap( QPixmap::fromMimeSource( "yellowLED.png" ));
