@@ -4,23 +4,8 @@ using namespace std;
 
 // **** Functions ****
 
-void k2::init_k2(int p)
-{
-    const char *sp;
-    sp =  "/dev/ttyS0"; // just to prevent null pointers
-    switch(p)
-    {
-    case 1:
- sp =  "/dev/ttyS0";
- break;
-    case 2:
- sp = "/dev/ttyS1";
- break; 
-    case 3:
- sp = "/dev/usb/tts/0";
- break;  
-    }
-    
+void k2::init_k2(const char *sp)
+{    
     fd = open(sp, O_RDWR | O_NDELAY );
     if (fd < 0)
     {
