@@ -40,7 +40,7 @@ class k2
  public:
 
 // open up serial port
-   void init_k2(int);
+   void init_k2(const char *);
  
 // read K2 data
    QString read_k2(void);
